##  Changing the Fact Sheet Color
Follow these steps:
  1. On the fact sheet configuration page, click Edit on the fact sheet header.
  2. In the right-side panel, click the current color under Color, then select or enter a new color value.
  3. Save the changes.


The color associated with a fact sheet changes everywhere in the workspace.
